Welcome to myTk's documentation!
================================

.. toctree::
   :maxdepth: 2
   :caption: Contents

   readme

.. toctree::
   :maxdepth: 2
   :caption: API Reference

   api/core
   api/widgets
   api/data
   api/visualization
   api/utilities


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
